@@ -1,5 +1,5 @@
 package Statocles;
-$Statocles::VERSION = '0.077';
+our $VERSION = '0.078';
 # ABSTRACT: A static site generator
 
 # The currently-running site.
@@ -31,7 +31,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.077
+version 0.078
 
 =head1 SYNOPSIS
 
@@ -142,12 +142,16 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Joel Berger Kent Fredric tadegenban Vladimir Lettiev William Lindley
+=for stopwords Doug Bell Joel Berger Kent Fredric tadegenban Vladimir Lettiev William Lindley
 
 =over 4
 
 =item *
 
+Doug Bell <doug@preaction.me>
+
+=item *
+
 Joel Berger <joel.a.berger@gmail.com>
 
 =item *
